"""
This package contains the high-level Python interface to the particle
system.

Also see the :mod:`panda3d.physics` module, which contains the C++
implementation of the particle system.

For more information about the particle system, see the :ref:`particle-effects`
page in the manual.
"""
